#include "vms_db_module.h"
#include <stdio.h>
#include <string>
#include <string.h>

#define UPDATE	1
#define INSERT	2
#define DELETE	3
#define SELECT	4

using namespace std;

PyroSMSCDB	*db = NULL;
string		db_user, db_password, db_name, query;
int			operation;

void doSelect();
void doUpdate();
void doInsert();
void doDelete();

int main(int argc, char*argv[])
{
	if ( argc != 6 )
	{
		printf("Usage: vms_db_module \"<db_user>\" \"<db_pasword>\" \"<db_name>\" <SELECT:UPDATE:INSERT:DELETE> \"<query>\"\n");
		exit(1);
	}
	else
	{
		if(strcasecmp(argv[4], "SELECT") == 0)
		{
			operation = SELECT;			
		}
		else if (strcasecmp(argv[4], "INSERT") == 0)
		{
			operation = INSERT;
		}
		else if (strcasecmp(argv[4], "UPDATE") == 0)
		{
			operation = UPDATE;
		}
		else if (strcasecmp(argv[4], "DELETE") == 0)
		{
			operation = DELETE;
		}
		else
		{
			printf("Usage: vms_db_module \"<db_user>\" \"<db_pasword>\" \"<db_name>\" <SELECT:UPDATE:INSERT:DELETE>\"<query>\"\n");
			exit(1);
		}

		db_user = argv[1];
		db_password = argv[2];
		db_name = argv[3];
		query = argv[5];
		
		//printf("Query:%s\n", query.c_str());
		
		db = new PyroSMSCDB( db_user, db_password, db_name);

		if ( !db->ConnectToDB() )
		{
			printf("Error in connecting to the database:%s\n", db->error.c_str());
			delete db;
			exit(1);
		}
		else
		{
			switch(operation)
			{
			case SELECT:
				doSelect();
				break;
			case INSERT:
				doInsert();
				break;
			case DELETE:
				doDelete();
				break;
			case UPDATE:
				doUpdate();
				break;
			}
			db->Disconnect();
		}
		delete db;
	}
	
	return 0;
}

void doSelect()
{
	ResultSet	*rs = NULL;
	int			len = 0;

	rs = db->GetDataFromSelect(query);
	if ( rs != NULL )
	{
		OCCI_STD_NAMESPACE::vector<oracle::occi::MetaData> columns = rs->getColumnListMetaData();
		
		//cout << "Total Rows:" << columns.size() << endl;
		/*
		while ( len <= columns.size() )
		{
			cout << columns[len].name << ",";
		}
		*/
		try
		{
			while(rs->next())
			{
				for (int i=1; i<=columns.size(); i++)
				{
					if ( i > 1 )
						cout << ",";
					cout << rs->getString(i) ;
				}
				cout << endl;
			}
			db->CloseResultSet(rs);
			rs = NULL;
		}
		catch(SQLException ex)
		{
			cout << "Exception:" << db->error.c_str() << endl;
			if ( rs != NULL )
				db->CloseResultSet(rs);
		}
	}			
}

void doUpdate()
{

	if ( !db->MakeUpdate(query) )
	{
		printf("Error in updating row:%s\n", db->error.c_str());
	}
	else
	{
		printf("%d rows updated\n", db->effectedRows);
	}
}

void doInsert()
{
	if ( !db->MakeUpdate(query) )
	{
		printf("Error in inserting  row:%s\n", db->error.c_str());
	}
	else
	{
		printf("%d rows inserted\n", db->effectedRows);
	}
}


void doDelete()
{
	if ( !db->MakeUpdate(query) )
	{
		printf("Error in deleting row:%s\n", db->error.c_str());
	}
	else
	{
		printf("%d rows deleted\n", db->effectedRows);
	}
}

